import { Component, OnInit, ViewChild, inject } from '@angular/core';
import { STColumn, STComponent } from '@delon/abc/st';
import { SFSchema } from '@delon/form';
import { ModalHelper, _HttpClient } from '@delon/theme';
import { SHARED_IMPORTS } from '@shared';
import { DataVCardComponent } from '../card/card.component';
import * as echarts from 'echarts';
import { AgGridAngular } from 'ag-grid-angular';
import { DataVTitleComponent } from '../title/title.component';
import { ColDef } from 'ag-grid-community'; // Column Definition Type Interface
import { NzProgressModule } from 'ng-zorro-antd/progress';
import { NzBadgeModule } from 'ng-zorro-antd/badge';

// 基于准备好的dom，初始化echarts实例
//var myChart = echarts.init(document.getElementById('c1'));
type EChartsOption = echarts.EChartsOption;

@Component({
  selector: 'app-data-v-s1',
  standalone: true,
  imports: [NzBadgeModule, NzProgressModule, AgGridAngular, DataVCardComponent, DataVTitleComponent, ...SHARED_IMPORTS],
  templateUrl: './s1.component.html',
  styleUrls: ['./s1.component.less']
})
export class DataVS1Component implements OnInit {
  private readonly http = inject(_HttpClient);
  private readonly modal = inject(ModalHelper);

  rowData = [
    {
      rwmc: '任务1',
      rwms: '任务描述1',
      kssj: '2024-1-1',
      jhwcsj: '2024-1-2',
      sfcq: '否',
      dqzt: '正常',
      dqjd: '节点1',
      sjwcsj: '2024-1-2',
      bjmc: '报警1',
      bjms: '报警描述1',
      bjsj: '2024-1-1',
      gzyy: '-',
      clff: '-',
      tzsj: '2024-1-2',
      zycd: '一般',
      tzmc: '系统提示',
      tznr: '账户登录',
      fj: '-'
    },
    {
      rwmc: '任务2',
      rwms: '任务描述2',
      kssj: '2024-1-2',
      jhwcsj: '2024-1-3',
      sfcq: '否',
      dqzt: '正常',
      dqjd: '节点2',
      sjwcsj: '2024-1-2',
      bjmc: '报警2',
      bjms: '报警描述2',
      bjsj: '2024-1-2',
      gzyy: '-',
      clff: '-',
      tzsj: '2024-1-2',
      zycd: '一般',
      tzmc: '系统提示',
      tznr: '账户登录',
      fj: '-'
    },
    {
      rwmc: '任务3',
      rwms: '任务描述3',
      kssj: '2024-1-3',
      jhwcsj: '2024-1-4',
      sfcq: '否',
      dqzt: '正常',
      dqjd: '节点3',
      sjwcsj: '2024-1-2',
      bjmc: '报警3',
      bjms: '报警描述3',
      bjsj: '2024-1-3',
      gzyy: '-',
      clff: '-',
      tzsj: '2024-1-2',
      zycd: '一般',
      tzmc: '系统提示',
      tznr: '账户登录',
      fj: '-'
    },
    {
      rwmc: '任务4',
      rwms: '任务描述4',
      kssj: '2024-1-4',
      jhwcsj: '2024-1-5',
      sfcq: '否',
      dqzt: '正常',
      dqjd: '节点4',
      sjwcsj: '2024-1-2',
      bjmc: '报警4',
      bjms: '报警描述4',
      bjsj: '2024-1-4',
      gzyy: '-',
      clff: '-',
      tzsj: '2024-1-2',
      zycd: '一般',
      tzmc: '系统提示',
      tznr: '账户登录',
      fj: '-'
    },
    {
      rwmc: '任务5',
      rwms: '任务描述5',
      kssj: '2024-1-5',
      jhwcsj: '2024-1-6',
      sfcq: '否',
      dqzt: '正常',
      dqjd: '节点5',
      sjwcsj: '2024-1-2',
      bjmc: '报警5',
      bjms: '报警描述5',
      bjsj: '2024-1-5',
      gzyy: '-',
      clff: '-',
      tzsj: '2024-1-2',
      zycd: '一般',
      tzmc: '系统提示',
      tznr: '账户登录',
      fj: '-'
    }
  ];

  colDefs1: ColDef[] = [
    { headerName: '时间', field: 'rwmc', flex: 1 },
    { headerName: '系统/设备', field: 'rwms', flex: 1 },
    { headerName: '操作描述', field: 'kssj', flex: 1 },
    { headerName: '操作人员', field: 'jhwcsj', flex: 1 }
  ];

  colDefs2: ColDef[] = [
    { headerName: '序号', field: 'rwmc', flex: 1 },
    { headerName: '时间', field: 'kssj', flex: 2 },
    { headerName: '任务描述', field: 'rwms', flex: 1 },
    { headerName: '等级', field: 'dqzt', flex: 1.5 }
  ];

  ngOnInit(): void {
    var c1 = document.getElementById('c1')!;
    //c1.style.left = '10%';
    //c1.style.top = '50%';
    //c1.style.transform = 'translate(-50%, -50%)';

    var c1Chart = echarts.init(c1);
    var c2 = document.getElementById('c2')!;
    var c2Chart = echarts.init(c2);
    let optionC = {
      tooltip: {
        formatter: '{a} <br/>{b} : {c}%'
      },
      series: [
        {
          name: 'Pressure',
          type: 'gauge',
          progress: {
            show: true
          },
          detail: {
            valueAnimation: true,
            formatter: '{value}'
          },
          data: [
            {
              value: 97,
              name: '百分比'
            }
          ]
        }
      ]
    };

    var d1 = document.getElementById('d1');
    var d1Chart = echarts.init(d1, 'dark');
    var d2 = document.getElementById('d2');
    var d2Chart = echarts.init(d2, 'dark');
    var d3 = document.getElementById('d3');
    var d3Chart = echarts.init(d3, 'dark');

    var optionD1;
    optionD1 = {
      title: {
        text: '全水',
        subtext: '(kg/kg)'
      },
      tooltip: {
        trigger: 'axis'
      },
      legend: {
        data: ['超差样数量', '不合格样数量']
      },
      toolbox: {
        show: false,
        feature: {
          dataView: { show: true, readOnly: false },
          magicType: { show: true, type: ['line', 'bar'] },
          restore: { show: true },
          saveAsImage: { show: true }
        }
      },
      calculable: true,
      xAxis: [
        {
          type: 'category',
          // prettier-ignore
          data: ['1', '2', '3', '4', '5', '6', '7', '8', '9', '10', '11', '12']
        }
      ],
      yAxis: [
        {
          type: 'value'
        }
      ],
      series: [
        {
          name: '超差样数量',
          type: 'line',
          data: [2.0, 4.9, 7.0, 23.2, 25.6, 76.7, 135.6, 162.2, 32.6, 20.0, 6.4, 3.3],
          markPoint: {
            data: [
              { type: 'max', name: 'Max' },
              { type: 'min', name: 'Min' }
            ]
          }
        },
        {
          name: '不合格样数量',
          type: 'bar',
          data: [2.6, 5.9, 9.0, 26.4, 28.7, 70.7, 175.6, 182.2, 48.7, 18.8, 6.0, 2.3],
          markPoint: {
            data: [
              { name: 'Max', value: 182.2, xAxis: 7, yAxis: 183 },
              { name: 'Min', value: 2.3, xAxis: 11, yAxis: 3 }
            ]
          },
          markLine: {
            data: [{ type: 'average', name: 'Avg' }]
          }
        }
      ]
    };

    var optionD2;
    optionD2 = {
      title: {
        text: '热值',
        subtext: '(kg/kg)'
      },
      tooltip: {
        trigger: 'axis'
      },
      legend: {
        data: ['超差样数量', '不合格样数量']
      },
      toolbox: {
        show: false,
        feature: {
          dataView: { show: true, readOnly: false },
          magicType: { show: true, type: ['line', 'bar'] },
          restore: { show: true },
          saveAsImage: { show: true }
        }
      },
      calculable: true,
      xAxis: [
        {
          type: 'category',
          // prettier-ignore
          data: ['1', '2', '3', '4', '5', '6', '7', '8', '9', '10', '11', '12']
        }
      ],
      yAxis: [
        {
          type: 'value'
        }
      ],
      series: [
        {
          name: '超差样数量',
          type: 'line',
          data: [2.0, 4.9, 7.0, 23.2, 25.6, 76.7, 135.6, 162.2, 32.6, 20.0, 6.4, 3.3],
          markPoint: {
            data: [
              { type: 'max', name: 'Max' },
              { type: 'min', name: 'Min' }
            ]
          }
        },
        {
          name: '不合格样数量',
          type: 'bar',
          data: [2.6, 5.9, 9.0, 26.4, 28.7, 70.7, 175.6, 182.2, 48.7, 18.8, 6.0, 2.3],
          markPoint: {
            data: [
              { name: 'Max', value: 182.2, xAxis: 7, yAxis: 183 },
              { name: 'Min', value: 2.3, xAxis: 11, yAxis: 3 }
            ]
          },
          markLine: {
            data: [{ type: 'average', name: 'Avg' }]
          }
        }
      ]
    };

    var optionD3;
    optionD3 = {
      title: {
        text: '全硫',
        subtext: '(kg/kg)'
      },
      tooltip: {
        trigger: 'axis'
      },
      legend: {
        data: ['超差样数量', '不合格样数量']
      },
      toolbox: {
        show: false,
        feature: {
          dataView: { show: true, readOnly: false },
          magicType: { show: true, type: ['line', 'bar'] },
          restore: { show: true },
          saveAsImage: { show: true }
        }
      },
      calculable: true,
      xAxis: [
        {
          type: 'category',
          // prettier-ignore
          data: ['1', '2', '3', '4', '5', '6', '7', '8', '9', '10', '11', '12']
        }
      ],
      yAxis: [
        {
          type: 'value'
        }
      ],
      series: [
        {
          name: '超差样数量',
          type: 'line',
          data: [2.0, 4.9, 7.0, 23.2, 25.6, 76.7, 135.6, 162.2, 32.6, 20.0, 6.4, 3.3],
          markPoint: {
            data: [
              { type: 'max', name: 'Max' },
              { type: 'min', name: 'Min' }
            ]
          }
        },
        {
          name: '不合格样数量',
          type: 'bar',
          data: [2.6, 5.9, 9.0, 26.4, 28.7, 70.7, 175.6, 182.2, 48.7, 18.8, 6.0, 2.3],
          markPoint: {
            data: [
              { name: 'Max', value: 182.2, xAxis: 7, yAxis: 183 },
              { name: 'Min', value: 2.3, xAxis: 11, yAxis: 3 }
            ]
          },
          markLine: {
            data: [{ type: 'average', name: 'Avg' }]
          }
        }
      ]
    };

    optionD1 && d1Chart.setOption(optionD1);
    optionD2 && d2Chart.setOption(optionD2);
    optionD3 && d3Chart.setOption(optionD3);

    c1Chart.setOption(optionC);
    c2Chart.setOption(optionC);

    // myChart.setOption({
    //   title: {
    //     text: 'ECharts 入门示例'
    //   },
    //   tooltip: {},
    //   xAxis: {
    //     data: ['衬衫', '羊毛衫', '雪纺衫', '裤子', '高跟鞋', '袜子']
    //   },
    //   yAxis: {},
    //   series: [
    //     {
    //       name: '销量',
    //       type: 'bar',
    //       data: [5, 20, 36, 10, 10, 20]
    //     }
    //   ]
    // });
  }

  add(): void {}
}
